@@ -1,17 +1,24 @@
 package Protocol::XMPP::Element::Auth;
+BEGIN {
+  $Protocol::XMPP::Element::Auth::VERSION = '0.002';
+}
 use strict;
 use warnings FATAL => 'all';
-use 5.10.0;
+use 5.010;
 use parent qw(Protocol::XMPP::ElementBase);
 
 =head1 NAME
 
 =head1 SYNOPSIS
 
+=head1 VERSION
+
+version 0.002
+
 =head1 DESCRIPTION
 
 =head1 METHODS
 
 =cut
 
-1;
+1;
\ No newline at end of file
