@@ -1,13 +1,20 @@
 package Protocol::XMPP::Element::JID;
+BEGIN {
+  $Protocol::XMPP::Element::JID::VERSION = '0.002';
+}
 use strict;
 use warnings FATAL => 'all';
-use 5.10.0;
+use 5.010;
 use parent qw(Protocol::XMPP::TextElement);
 
 =head1 NAME
 
 =head1 SYNOPSIS
 
+=head1 VERSION
+
+version 0.002
+
 =head1 DESCRIPTION
 
 =head1 METHODS
@@ -23,4 +30,4 @@ sub on_text_complete {
 	# $self->write_xml([ 'iq', type => 'set', id => 'xyz', _content => [ [ 'session', _ns => 'xmpp-session' ] ] ]);
 }
 
-1;
+1;
\ No newline at end of file
