@@ -1,13 +1,20 @@
 package Protocol::XMPP::Element::Mechanism;
+BEGIN {
+  $Protocol::XMPP::Element::Mechanism::VERSION = '0.002';
+}
 use strict;
 use warnings FATAL => 'all';
-use 5.10.0;
+use 5.010;
 use parent qw(Protocol::XMPP::TextElement);
 
 =head1 NAME
 
 Protocol::XMPP::Mechanism - information on available auth mechanisms
 
+=head1 VERSION
+
+version 0.002
+
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
@@ -50,4 +57,4 @@ sub end_element {
 	$self;
 }
 
-1;
+1;
\ No newline at end of file
