@@ -1,13 +1,20 @@
 package Protocol::XMPP::Element::Mechanisms;
+BEGIN {
+  $Protocol::XMPP::Element::Mechanisms::VERSION = '0.002';
+}
 use strict;
 use warnings FATAL => 'all';
-use 5.10.0;
+use 5.010;
 use parent qw(Protocol::XMPP::ElementBase);
 
 =head1 NAME
 
 =head1 SYNOPSIS
 
+=head1 VERSION
+
+version 0.002
+
 =head1 DESCRIPTION
 
 =head1 METHODS
@@ -28,4 +35,4 @@ sub end_element {
 	$self;
 }
 
-1;
+1;
\ No newline at end of file
