@@ -1,13 +1,20 @@
 package Protocol::XMPP::Element::Success;
+BEGIN {
+  $Protocol::XMPP::Element::Success::VERSION = '0.002';
+}
 use strict;
 use warnings FATAL => 'all';
-use 5.10.0;
+use 5.010;
 use parent qw(Protocol::XMPP::ElementBase);
 
 =head1 NAME
 
 Protocol::XMPP::Success - indicate success for an operation
 
+=head1 VERSION
+
+version 0.002
+
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
@@ -24,4 +31,4 @@ sub end_element {
 	$self->is_authorised(1);
 }
 
-1;
+1;
\ No newline at end of file
