@@ -1,7 +1,10 @@
 package Protocol::XMPP::User;
+BEGIN {
+  $Protocol::XMPP::User::VERSION = '0.002';
+}
 use strict;
 use warnings FATAL => 'all';
-use 5.10.0;
+use 5.010;
 
 use Protocol::XMPP::Roster;
 
